@@ -1,4 +1,4 @@
-"""Showcases RGB colourspace volume computations."""
+"""Showcase RGB colourspace volume computations."""
 
 import colour
 from colour.utilities import message_box
@@ -9,9 +9,7 @@ if __name__ == "__main__":
     message_box("RGB Colourspace Volume Computations")
 
     message_box('Computing the "ProPhoto RGB" RGB colourspace limits.')
-    limits = colour.RGB_colourspace_limits(
-        colour.RGB_COLOURSPACES["ProPhoto RGB"]
-    )
+    limits = colour.RGB_colourspace_limits(colour.RGB_COLOURSPACES["ProPhoto RGB"])
     print(limits)
 
     print("\n")
